==> opencart_v1.2.6.zip: opencart_v1.2.6/upload/catalog/language/english/account/create.php <==
<?php
// Heading 
$_['heading_title']        = 'Create Account';

// Text
$_['text_account']         = 'Account';
$_['text_create']          = 'Register';
$_['text_account_already'] = 'If you already have an account with us, please login at the <a href="%s">login page</a>.';
$_['text_your_details']    = 'Your Personal Details';
$_['text_your_address']    = 'Your Address';
$_['text_newsletter']      = 'Newsletter';
$_['text_your_password']   = 'Your Password';

// Entry
$_['entry_firstname']      = 'First Name:';
$_['entry_lastname']       = 'Last Name:';
$_['entry_email']          = 'E-Mail:';
$_['entry_company']        = 'Company:';
$_['entry_address_1']      = 'Address 1:';
$_['entry_address_2']      = 'Address 2:';
$_['entry_postcode']       = 'Post Code:';
$_['entry_city']           = 'City:';
$_['entry_country']        = 'Country:';
$_['entry_zone']           = 'Region / State:';
$_['entry_telephone']      = 'Telephone:';
$_['entry_fax']            = 'Fax:';
$_['entry_newsletter']     = 'Subscribe:';
$_['entry_password']       = 'Password:';
$_['entry_confirm']        = 'Password Confirm:';

// Mail
$_['mail_subject']         = '%s - Thank you for registering';
$_['mail_line_1']          = 'Welcome and thank you for registering at %s!';
$_['mail_line_2']          = 'Your account has now been created and you can log in by using your email address and password by visiting our website or at the following URL:';
$_['mail_line_3']          = 'Upon logging in, you will be able to access other services including reviewing past orders, printing invoices and editing your account information.';
$_['mail_line_4']          = 'Thanks,';
$_['mail_line_5']          = 'Your Store';

// Error
$_['error_exists']         = 'Error: E-Mail Address is already registered!';
$_['error_firstname']      = 'First Name must be greater than 3 and less than 32 characters!';
$_['error_lastname']       = 'Last Name must be greater than 3 and less than 32 characters!';
$_['error_email']          = 'E-Mail Address does not appear to be valid!';
$_['error_password']       = 'Password must be greater than 3 and less than 20 characters!';
$_['error_confirm']        = 'Password confirmation does not match password!';
$_['error_address_1']      = 'Address 1 must be greater than 3 and less than 128 characters!';
$_['error_city']           = 'City must be greater than 3 and less than 128 characters!';
$_['error_telephone']      = 'Telephone must be greater than 3 and less than 32 characters!';
?>

==> opencart_v1.3.0.zip: opencart_v1.3.0/upload/catalog/language/english/account/create.php <==
<?php
// Heading 
$_['heading_title']        = 'Create Account';

// Text
$_['text_account']         = 'Account';
$_['text_create']          = 'Register';
$_['text_account_already'] = 'If you already have an account with us, please login at the <a href="%s">login page</a>.';
$_['text_your_details']    = 'Your Personal Details';
$_['text_your_address']    = 'Your Address';
$_['text_newsletter']      = 'Newsletter';
$_['text_your_password']   = 'Your Password';
$_['text_agree']           = 'I have read and agree to the <a onclick="window.open(\'%s\');"><b>%s</b></a>';

// Entry
$_['entry_firstname']      = 'First Name:';
$_['entry_lastname']       = 'Last Name:';
$_['entry_email']          = 'E-Mail:';
$_['entry_company']        = 'Company:';
$_['entry_address_1']      = 'Address 1:';
$_['entry_address_2']      = 'Address 2:';
$_['entry_postcode']       = 'Post Code:';
$_['entry_city']           = 'City:';
$_['entry_country']        = 'Country:';
$_['entry_zone']           = 'Region / State:';
$_['entry_telephone']      = 'Telephone:';
$_['entry_fax']            = 'Fax:';
$_['entry_newsletter']     = 'Subscribe:';
$_['entry_password']       = 'Password:';
$_['entry_confirm']        = 'Password Confirm:';

// Mail
$_['mail_subject']         = '%s - Thank you for registering';
$_['mail_line_1']          = 'Welcome and thank you for registering at %s!';
$_['mail_line_2']          = 'Your account has now been created and you can log in by using your email address and password by visiting our website or at the following URL:';
$_['mail_line_3']          = 'Upon logging in, you will be able to access other services including reviewing past orders, printing invoices and editing your account information.';
$_['mail_line_4']          = 'Thanks,';

// Error
$_['error_exists']         = 'Error: E-Mail Address is already registered!';
$_['error_firstname']      = 'First Name must be greater than 3 and less than 32 characters!';
$_['error_lastname']       = 'Last Name must be greater than 3 and less than 32 characters!';
$_['error_email']          = 'E-Mail Address does not appear to be valid!';
$_['error_password']       = 'Password must be greater than 3 and less than 20 characters!';
$_['error_confirm']        = 'Password confirmation does not match password!';
$_['error_address_1']      = 'Address 1 must be greater than 3 and less than 128 characters!';
$_['error_city']           = 'City must be greater than 3 and less than 128 characters!';
$_['error_telephone']      = 'Telephone must be greater than 3 and less than 32 characters!';
$_['error_agree']          = 'Error: You must agree to the %s!';
?>
